<?php

namespace Teknisa\CRM\Controller;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\CRM\Service\IntegracaoSmService;
use Teknisa\Libs\Util\ConnectionCustom;

class IntegracaoSmController {
    
    protected $integracaoService;
    
    public function __construct (IntegracaoSmService $integracaoService, ConnectionCustom $connectionCustom) {
        $this->integracaoService = $integracaoService;
        $this->connectionCustom        = $connectionCustom;
    }
    
    /**
     * Gera Evolução na oportunidade referente a proposta do SM.
     * 
     * @param Request  $request
     * @param Response $response
     */
    public function geraEvolucaoOportunidade(Request $request, Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0];
            $return = null;
            
            $entityManager = $this->connectionCustom->updateVpdConnection($row['requisitante']['nrorg']);
            
            if(!empty($row)){
                $this->validation($row);
                $return = $this->integracaoService->geraEvolucaoOportunidade($row, $response, $entityManager);
            }else{
                $response->setError(new Response\Error('Dados da Evolução não encontrados'));    
            }
            $response->setDataSets(array(new DataSet('EVOLUCAO', array($return))));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function geraProposta(Request $request, Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0];
            $rota = "/IntegracaoCrm/GeraProposta";
            $retorno = $this->integracaoService->geraProposta($row, $rota);
            $response->addDataset(new DataSet('INTEGRACAO', array($retorno)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    protected function validation($row){
        
        foreach ($row as $fieldGroup => $data) {
            switch ($fieldGroup) {
                case 'evolucao':
                    
                    if(empty($data['sentido']))
                        throw new \Exception('Sentido da Evolução não informado');
                        
                    if(empty($data['contato']))
                        throw new \Exception('Contato da Evolução não informado');
                        
                    if(empty($data['motivo']))
                        throw new \Exception('Motivo da Evolução não informado');
                        
                    if(empty($data['resultado']))
                        throw new \Exception('Resultado da Evolução não informado');
                        
                    if(empty($data['descricao']))
                        throw new \Exception('Descricao da Evolução não informado');
                        
                break;
                case 'oportunidade':
                    
                    if(empty($data['fase']))
                        throw new \Exception('Fase da Oportunidade não informada');
                    
                    if(empty($data['nrseqcontato']))
                        throw new \Exception('NRSEQCONTATO(PK do contato referente à oportunidade) não informado');
                    
                    if(empty($data['nrseqoport']))
                        throw new \Exception('NRSEQCONTATO(PK da oportunidade) não informado');
                    
                    if(empty($data['nrparcnegocio']))
                        throw new \Exception('NRPARCNEGOCIO(PK do parceiro referente à oportunidade) não informado');
                break;
                case 'proxima_tarefa':
                    if($data['gera_tarefa'] === 'S' && empty($data['data']))
                        throw new \Exception('O resultado da evolução obriga uma nova tarefa, mas a data da próxima tarefa não foi informada');
                break;
            }
        }
        
    }
}

?>