<?php
namespace Teknisa\CRM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Util\NovoCodigo;
use Teknisa\CRM\Util\Util;
use Teknisa\CRM\Service\crm00004000LeadSevice as LeadService;
use Zeedhi\Framework\Util\Functions;

class ImportacaoProspectFactory
{
    protected $entityManager;
    /** @var Environment */
    protected $environment;
    protected $leadService;
    protected $newCode;
    protected $dataset;
    protected $nrparcnegocio;
    protected $inconsistencias;
    public    $keys = array();
    
    public function __construct(EntityManager $entityManager, $environment, LeadService $leadService, $leadFactory) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->leadService = $leadService;
        $this->leadFactory = $leadFactory;
    }
    
    public function setDataset($dataset) {
        $this->keys = array();
        $this->dataset = $dataset;
        $this->validations();
    }
    
    public function setLead() {
        $this->setParcnegocio();
        $this->setParcnegocioInfo();
        $this->setParceria();
        $this->setCrmInterlocutor();
        $this->setEnderecoparc();
        $this->setComunicaparc();
        $this->setContato();
        $this->setCandidato();
    }
    
    public function setProspect() {
        $this->setNovoProspect();
        $this->setEnderecoProspect();
    }
    
    public function setEvolucao() {
        $this->geraEvolucao();
    }
    
    public function setTarefa() {
        $this->geraTarefa();
    }
    
    public function getOperadorResponsavel(){
        $cdoperadorResponsavel = empty($this->dataset['COD_OPERADOR_TAREFA']) ? $this->environment->getCdOperador() : $this->dataset['COD_OPERADOR_TAREFA'];
        
        if(!empty($this->dataset['COD_OPERADOR_TAREFA'])){
            $operador = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Operador')->findOneBy(
                    array(
                        'cdoperador' => str_pad($this->dataset['COD_OPERADOR_TAREFA'], 12, '0', STR_PAD_LEFT),
                        'nrorg' => $this->environment->getNrOrgTrab()
                    )
                );
            if (is_object($operador))
                $nrparcnegocioResponsavel = $operador->getNrparcnegocio();
            else
                $nrparcnegocioResponsavel = $this->dataset['NRPARCNEGOCIO_OPER'];
        }else{
            $nrparcnegocioResponsavel = $this->dataset['NRPARCNEGOCIO_OPER'];
        }        
                
        $this->dataset['CDOPERRESPONSAVEL'] = str_pad($cdoperadorResponsavel, 12, '0', STR_PAD_LEFT);
        $this->dataset['NRPARCRESPONSAVEL'] = $nrparcnegocioResponsavel;
    }
    
    private function setParcnegocio() {
        // PARCNEGOCIO
        $parcnegocio = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Parcnegocio')->findOneBy(
            array(
                'nrinscricaoparc' => Util::getSomenteNumeros($this->dataset['CNPJ']),
                'nrorg' => $this->environment->getNrOrgTrab()
            )
        );
        
        if (!is_object($parcnegocio)) {
            $nrparcnegocio = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "PARCNEGOCIO", 1, 10, false, false);
            $parcnegocio = new \Teknisa\Model\Geral\Entities\Parcnegocio();
            
            $parcnegocio->setNrparcnegocio($nrparcnegocio);
            $parcnegocio->setIdativo($this->dataset['ATIVO']);
            $parcnegocio->setNrorg($this->environment->getNrOrgTrab());
            $parcnegocio->setNmprincipalparc($this->dataset['RAZAO_SOCIAL']);
            $parcnegocio->setNmsecundariparc(empty($this->dataset['NOME_FANTASIA']) ? $this->dataset['RAZAO_SOCIAL'] : $this->dataset['NOME_FANTASIA']);
            $parcnegocio->setNrinscricaoparc(Util::getSomenteNumeros($this->dataset['CNPJ']));
            $parcnegocio->setCdsegmer($this->dataset['COD_SEGMENTO']);
            $parcnegocio->setCdoperresponsavel($this->dataset['CDOPERRESPONSAVEL']);
            $parcnegocio->setNrorginclusao($this->environment->getNrOrgTrab());
            $parcnegocio->setCdoperinclusao($this->environment->getCdOperador());
            $parcnegocio->setCdtipoparcprincipal($this->dataset['TIPODEPARCEIRO']);
            $parcnegocio->setCdtipoinscricao(Util::getTipoInscricao($this->dataset['CNPJ']));
            $parcnegocio->setDtnascifundparc(empty($this->dataset['DATA_DE_NASCIMENTO/FUNDACAO']) ? null : \Teknisa\Libs\Util\DateUtil::getDatadeString($this->dataset['DATA_DE_NASCIMENTO/FUNDACAO'], \Teknisa\Libs\Util\DateUtil::FORMATO_BRASILEIRO, true));
            $parcnegocio->setIdpessoafisica('N');
            $parcnegocio->setIdparcfundido('N');
            $parcnegocio->setIdinstituicao('N');
            $parcnegocio->setDtinclusao(new \DateTime());
            
            $this->entityManager->persist($parcnegocio);
            $this->entityManager->flush();
            
            // guarda o segquencia gerado para tabela
            $this->keys['NRPARCNEGOCIO'] = $nrparcnegocio;
        } else {
            throw new \Exception('Parceiro de Negócio já cadastrado, verifique o cadastro.');
        }
    }
    
    private function setParcnegocioInfo() {
        // PARCNEGOCIO
        $parcnegocioInfo = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\GerParcnegocioinfo')->findOneBy(
            array(
                'nrparcnegocio' => Util::getSomenteNumeros($this->keys['NRPARCNEGOCIO']),
                'nrorg' => $this->environment->getNrOrgTrab()
            )
        );

        if (!is_object($parcnegocioInfo)) {
            $parcnegocioInfo = new \Teknisa\Model\Geral\Entities\GerParcnegocioinfo();
            
            $parcnegocioInfo->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
            $parcnegocioInfo->setNrorg($this->environment->getNrOrgTrab());
            $parcnegocioInfo->setNmrespgeral(empty($this->dataset['NOME_DO_RESPONSAVEL_GERAL']) ? '' : $this->dataset['NOME_DO_RESPONSAVEL_GERAL']);
            $parcnegocioInfo->setNmpontoatendimento(empty($this->dataset['NOME_DO_PONTO_DE_ATENDIMENTO']) ? '' : $this->dataset['NOME_DO_PONTO_DE_ATENDIMENTO']);
            $parcnegocioInfo->setNrpontuacao(empty($this->dataset['PONTUACAO']) ? '' : $this->dataset['PONTUACAO']);
            $parcnegocioInfo->setCdintegracao(empty($this->dataset['NUMERO_DE_INTEGRACAO']) ? '' : $this->dataset['NUMERO_DE_INTEGRACAO']);
            $parcnegocioInfo->setDtinirelaciona(empty($this->dataset['DATA_DE_INICIO_RELACIONAMENTO']) ? null : \Teknisa\Libs\Util\DateUtil::getDatadeString($this->dataset['DATA_DE_INICIO_RELACIONAMENTO'], \Teknisa\Libs\Util\DateUtil::FORMATO_BRASILEIRO, true));
            
            $this->entityManager->persist($parcnegocioInfo);
            $this->entityManager->flush();
            
        } else {
            throw new \Exception('Parceiro de Negócio já possui dados adicionais.');
        }
    }

    private function setEnderecoparc() {
        $this->keys['NRENDERECOPARC'] = null;
        
        // ENDERECOPARC
        $endereco = $this->verificaCamposEndereco($this->dataset);
        if (!empty($endereco)) {
            $nrenderecoparc = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "ENDERECOPARC", 1, 10, false, false);
            $enderecoparc = new \Teknisa\Model\Geral\Entities\Enderecoparc();
            
            $enderecoparc->setNrenderecoparc($nrenderecoparc);
            $enderecoparc->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
            $enderecoparc->setCdtipoendereco('PRINCIPAL');
            $enderecoparc->setCdpais('0055');
            $enderecoparc->setSgestado(strtoupper(empty($this->dataset['UF__ESTADO']) ? '' : $this->dataset['UF__ESTADO'] ));
            $enderecoparc->setCdmunicipio($this->dataset['COD_MUNICIPIO']);
            $enderecoparc->setCdbairro(Util::getSomenteNumeros($this->dataset['BAIRRO']));
            $enderecoparc->setNmbairroendereco(strtoupper(empty($this->dataset['NOME_BAIRRO']) ? '' : $this->dataset['NOME_BAIRRO'] ));
            $enderecoparc->setDscompleendereco(empty($this->dataset['COMPLEMENTO']) ? '' : $this->dataset['COMPLEMENTO']);
            $enderecoparc->setNrcependereco(Util::getSomenteNumeros($this->dataset['CEP']));
            $enderecoparc->setDsendereco(empty($this->dataset['ENDERECO']) ? '' : $this->dataset['ENDERECO']);
            $enderecoparc->setNrimovelendereco(Util::getSomenteNumeros($this->dataset['NUMERO']));
            $enderecoparc->setIdativo($this->dataset['ATIVO']);
            $enderecoparc->setNrorg($this->environment->getNrOrgTrab());
            $enderecoparc->setNrorginclusao($this->environment->getNrOrgTrab());
            $enderecoparc->setCdoperinclusao($this->environment->getCdOperador());
            $enderecoparc->setDtinclusao(new \DateTime());
            
            $this->entityManager->persist($enderecoparc);
            $this->entityManager->flush();
            
            // guarda o segquencia gerado para tabela
            $this->keys['NRENDERECOPARC'] = $nrenderecoparc;
        }
    }

    private function setComunicaparc() {
        // COMUNICAPARC
        if (!empty($this->dataset['TELEFONE'])) {
            
            $nrcomunicapac = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "COMUNICAPARC", 1, 10, false, false);
            $comunicaparc = new \Teknisa\Model\Geral\Entities\Comunicaparc();
            
            $comunicaparc->setNrcomunicaparc($nrcomunicapac);
            $comunicaparc->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
            $comunicaparc->setCdformacomu('01');
            $comunicaparc->setNrenderecoparc($this->keys['NRENDERECOPARC']);
            $comunicaparc->setCdcomunicaparc($this->dataset['TELEFONE']);
            $comunicaparc->setIdativo($this->dataset['ATIVO']);
            $comunicaparc->setNrorg($this->environment->getNrOrgTrab());
            $comunicaparc->setNrorginclusao($this->environment->getNrOrgTrab());
            $comunicaparc->setCdoperinclusao($this->environment->getCdOperador());
            $comunicaparc->setDtinclusao(new \DateTime());
            
            $this->entityManager->persist($comunicaparc);
            $this->entityManager->flush();
            
            // guarda o segquencia gerado para tabela
            $this->keys['NRCOMUNICAPARC_1'] = $nrcomunicapac;
            
        }
        
        if (!empty($this->dataset['TELEFONE_2'])) {
            
            $nrcomunicapac = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "COMUNICAPARC", 1, 10, false, false);
            $comunicaparc = new \Teknisa\Model\Geral\Entities\Comunicaparc();
            
            $comunicaparc->setNrcomunicaparc($nrcomunicapac);
            $comunicaparc->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
            $comunicaparc->setCdformacomu('04');
            $comunicaparc->setNrenderecoparc($this->keys['NRENDERECOPARC']);
            $comunicaparc->setCdcomunicaparc($this->dataset['TELEFONE_2']);
            $comunicaparc->setIdativo($this->dataset['ATIVO']);
            $comunicaparc->setNrorg($this->environment->getNrOrgTrab());
            $comunicaparc->setNrorginclusao($this->environment->getNrOrgTrab());
            $comunicaparc->setCdoperinclusao($this->environment->getCdOperador());
            $comunicaparc->setDtinclusao(new \DateTime());
            
            $this->entityManager->persist($comunicaparc);
            $this->entityManager->flush();
            
            // guarda o segquencia gerado para tabela
            $this->keys['NRCOMUNICAPARC_2'] = $nrcomunicapac;
            
        }
        
        if (!empty($this->dataset['EMAIL'])) {
            
            $nrcomunicapac = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "COMUNICAPARC", 1, 10, false, false);
            $comunicaparc = new \Teknisa\Model\Geral\Entities\Comunicaparc();
            
            $comunicaparc->setNrcomunicaparc($nrcomunicapac);
            $comunicaparc->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
            $comunicaparc->setCdformacomu('05');
            $comunicaparc->setNrenderecoparc($this->keys['NRENDERECOPARC']);
            $comunicaparc->setCdcomunicaparc($this->dataset['EMAIL']);
            $comunicaparc->setIdativo($this->dataset['ATIVO']);
            $comunicaparc->setNrorg($this->environment->getNrOrgTrab());
            $comunicaparc->setNrorginclusao($this->environment->getNrOrgTrab());
            $comunicaparc->setCdoperinclusao($this->environment->getCdOperador());
            $comunicaparc->setDtinclusao(new \DateTime());
            
            $this->entityManager->persist($comunicaparc);
            $this->entityManager->flush();
            
            // guarda o segquencia gerado para tabela
            $this->keys['NRCOMUNICAPARC_3'] = $nrcomunicapac;
            
        }
    }

    private function setContato() {
        // CONTATO
        $nrcontato = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "NRSEQCONTATO", 1, 10, false, false);
        $contato = new \Teknisa\Model\Crm\Entities\Contato();
        
        $contato->setNrcontato($nrcontato);
        $contato->setNrseqcontato($nrcontato);
        $contato->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
        $contato->setNrorg($this->environment->getNrOrgTrab());
        $contato->setDthrcontato(new \DateTime());
        $contato->setDsrefecont(substr('Referente ao Lead '.$this->dataset['RAZAO_SOCIAL'], 0, 59));
        $contato->setIdstatuscont('A');
        $contato->setIdtpcontato('P');
        $contato->setIdgerafatura('SIM');
        $contato->setCdopercont($this->dataset['CDOPERRESPONSAVEL']);
        $contato->setNrorginclusao($this->environment->getNrOrgTrab());
        $contato->setCdoperinclusao($this->environment->getCdOperador());
        $contato->setDtinclusao(new \DateTime());
        
        $this->entityManager->persist($contato);
        $this->entityManager->flush();
        
        // guarda o segquencia gerado para tabela
        $this->keys['NRSEQCONTATO'] = $nrcontato;
    }
    
    private function setCandidato() {
        // CRM_CANDIDATO
        $nrcandidato = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "CANDIDATO9999", 1, 10, false, false);
        $crmCandidato = new \Teknisa\Model\Crm\Entities\CrmCandidato();
        
        $crmCandidato->setNrcandidato($nrcandidato);
        $crmCandidato->setNrorg($this->environment->getNrOrgTrab());
        $crmCandidato->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
        $crmCandidato->setNrseqcontato($this->keys['NRSEQCONTATO']);
        $crmCandidato->setNrcontato($this->keys['NRSEQCONTATO']);
        $crmCandidato->setNrparcpropri($this->dataset['NRPARCRESPONSAVEL']); // parceiro de negócio do operador logado
        $crmCandidato->setIdtpijurcan(Util::getTipoInscricao($this->dataset['CNPJ'], 'CRM_CANDIDATO'));
        $crmCandidato->setNrinsjurcan(Util::getSomenteNumeros($this->dataset['CNPJ']));
        $crmCandidato->setNmcandidato($this->dataset['RAZAO_SOCIAL']);
        $crmCandidato->setNmfantcan((empty($this->dataset['NOME_FANTASIA']) ? $this->dataset['RAZAO_SOCIAL'] : $this->dataset['RAZAO_SOCIAL']));
        $crmCandidato->setDsemailcan($this->dataset['EMAIL']);
        $crmCandidato->setDstelefonecan($this->dataset['TELEFONE']);
        $crmCandidato->setCdsegmer($this->dataset['COD_SEGMENTO']);
        $crmCandidato->setNrfunccan(Util::getSomenteNumeros($this->dataset['NR_FUNCIONARIOS']));
        $crmCandidato->setCdmododivulg($this->dataset['COMO_CHEGOU_ATE_NOS']);
        $crmCandidato->setCdpais('0055');
        $crmCandidato->setSgestado(strtoupper($this->dataset['UF__ESTADO']));
        $crmCandidato->setCdmunicipio($this->dataset['COD_MUNICIPIO']);
        $crmCandidato->setNmbairrocan(strtoupper($this->dataset['NOME_BAIRRO']));
        $crmCandidato->setNrimovelendereco(Util::getSomenteNumeros($this->dataset['NUMERO']));
        $crmCandidato->setCdbairro(Util::getSomenteNumeros($this->dataset['BAIRRO']));
        $crmCandidato->setIdstatuscan('2');
        $crmCandidato->setIdparcfundido('N');
        /*Modificado para verificar se é importação de lead*/
        $crmCandidato->setIdativo($this->dataset['TIPODEPARCEIRO'] == "CANDIDATO" ? 'S' : 'N'); // insere inativo pois já será convertido em prospect
        $crmCandidato->setNrorginclusao($this->environment->getNrOrgTrab());
        $crmCandidato->setCdoperinclusao($this->environment->getCdOperador());
        $crmCandidato->setDtinclusao(new \DateTime());
        
        $this->entityManager->persist($crmCandidato);
        $this->entityManager->flush();
        
        // guarda o segquencia gerado para tabela
        $this->keys['NRCANDIDATO'] = $nrcandidato;
    }

    private function setNovoProspect() {
        // PROSPECT
        $cdprospect = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "PROSPECT", 1, 21, false, false);
        $prospect = new \Teknisa\Model\Crm\Entities\Prospect();
        
        $prospect->setCdprospect($cdprospect);
        $prospect->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
        $prospect->setNrparcresprosp($this->dataset['NRPARCRESPONSAVEL']); // parceiro de negócio do operador logado);
        $prospect->setNrorg($this->environment->getNrOrgTrab());
        $prospect->setIdtpijurpros(Util::getTipoInscricao($this->dataset['CNPJ'], 'CRM_CANDIDATO'));
        $prospect->setNrinsjurpros(Util::getSomenteNumeros($this->dataset['CNPJ']));
        $prospect->setNmrazsocpros($this->dataset['RAZAO_SOCIAL']);
        $prospect->setNmfantpros((empty($this->dataset['NOME_FANTASIA']) ? $this->dataset['RAZAO_SOCIAL'] : $this->dataset['RAZAO_SOCIAL']));
        $prospect->setCdsegmer($this->dataset['COD_SEGMENTO']);
        $prospect->setNrfuncpros(Util::getSomenteNumeros($this->dataset['NR_FUNCIONARIOS']));
        $prospect->setCdmododivulg($this->dataset['COMO_CHEGOU_ATE_NOS']);
        $prospect->setVrfatupros(Util::getSomenteNumeros(explode(',', $this->dataset['VALOR_FATURAMENTO']))[0]);
        $prospect->setIdparcfundido('N');
        $prospect->setIdativo($this->dataset['ATIVO']); 
        $prospect->setIdligextpros('S');
        $prospect->setIdpripubpros('V');
        $prospect->setIdutlalvpros('N');
        $prospect->setNrorginclusao($this->environment->getNrOrgTrab());
        $prospect->setCdoperinclusao($this->environment->getCdOperador());
        $prospect->setDtinclusao(new \DateTime());
        
        $this->entityManager->persist($prospect);
        $this->entityManager->flush();
        
        // guarda o segquencia gerado para tabela
        $this->keys['CDPROSPECT'] = $cdprospect;
    }
    
    private function setEnderecoProspect() {
        // ENDEPROSPECT
        if (!empty($this->dataset['ENDERECO']) || $this->dataset['ENDERECO'] != '') {
            $endeprospect = new \Teknisa\Model\Academico\Entities\Endeprospect();
            
            $endeprospect->setCdprospect($this->keys['CDPROSPECT']);
            $endeprospect->setNrenderecoparc($this->keys['NRENDERECOPARC']);
            $endeprospect->setIdtpendepros('P');
            $endeprospect->setCdpais('0055');
            $endeprospect->setSgestado(strtoupper($this->dataset['UF__ESTADO']));
            $endeprospect->setCdmunicipio(Util::getSomenteNumeros($this->dataset['COD_MUNICIPIO']));
            $endeprospect->setDsendepros(substr((substr($this->dataset['ENDERECO'], 0, 40) . ' - ' . $this->dataset['NUMERO']), 0, 50));
            $endeprospect->setDscompendpro($this->dataset['COMPLEMENTO']);
            $endeprospect->setNmbairpros(strtoupper($this->dataset['NOME_BAIRRO']));
            $endeprospect->setNrceppros(Util::getSomenteNumeros($this->dataset['CEP']));
            $endeprospect->setNrtelepros(Util::getSomenteNumeros($this->dataset['TELEFONE']));
            $endeprospect->setNrtelepros1(Util::getSomenteNumeros($this->dataset['TELEFONE_2']));
            $endeprospect->setDsemailpros($this->dataset['EMAIL']);
            $endeprospect->setIdativo($this->dataset['ATIVO']);
            $endeprospect->setNrorg($this->environment->getNrOrgTrab());
            $endeprospect->setNrorginclusao($this->environment->getNrOrgTrab());
            $endeprospect->setCdoperinclusao($this->environment->getCdOperador());
            $endeprospect->setDtinclusao(new \DateTime());
            
            $this->entityManager->persist($endeprospect);
            $this->entityManager->flush();
        }
    }
    
    private function setCrmInterlocutor() {
        // INTEPROSP
        if (!empty($this->dataset['NOME_INTERLOCUTOR']) || $this->dataset['NOME_INTERLOCUTOR'] != '') {
            $nrSeqinterlocutor = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "CRM_INTERLOCUTOR", 1, 10, false, false);
            $crmInterlocutor = new \Teknisa\Model\Crm\Entities\CrmInterlocutor();
            
            $crmInterlocutor->setNrseqinterlocutor($nrSeqinterlocutor);
            $crmInterlocutor->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
            $crmInterlocutor->setNminterlocutor($this->dataset['NOME_INTERLOCUTOR']);
            $crmInterlocutor->setCdcargointerloc(is_numeric($this->dataset['CARGO']) ? str_pad($this->dataset['CARGO'], 5, 0, STR_PAD_LEFT) : '');
            $crmInterlocutor->setIdativo($this->dataset['ATIVO']);
            $crmInterlocutor->setIdrecebepresente($this->dataset['RECEBE_PRESENTE']);
            $crmInterlocutor->setCdpais('0055');
            $crmInterlocutor->setEmailinterloc($this->dataset['EMAIL__INTERLOCUTOR']);
            $crmInterlocutor->setNrtelefone1($this->dataset['TELEFONE__INTERLOCUTOR']);
            $crmInterlocutor->setDtnascimento(empty($this->dataset['DATA_DE_NASCIMENTO__INTERLOCUTOR']) ? null : \Teknisa\Libs\Util\DateUtil::getDatadeString($this->dataset['DATA_DE_NASCIMENTO__INTERLOCUTOR'], \Teknisa\Libs\Util\DateUtil::FORMATO_BRASILEIRO, true));
            $crmInterlocutor->setNrcepinterlocutor(Util::getSomenteNumeros($this->dataset['CEP__INTERLOCUTOR']));
            $crmInterlocutor->setSgestado(strtoupper($this->dataset['UF__ESTADO__INTERLOCUTOR']));
            $crmInterlocutor->setCdmunicipio(Util::getSomenteNumeros($this->dataset['COD_MUNICIPIO__INTERLOCUTOR']));
            $crmInterlocutor->setCdbairro(Util::getSomenteNumeros($this->dataset['BAIRRO__INTERLOCUTOR']));
            $crmInterlocutor->setDsendeinterlocutor($this->dataset['ENDERECO__INTERLOCUTOR']);
            $crmInterlocutor->setNrendeinterlocutor(Util::getSomenteNumeros($this->dataset['NUMERO__INTERLOCUTOR']));
            $crmInterlocutor->setDscompinterlocutor($this->dataset['COMPLEMENTO__INTERLOCUTOR']);
            $crmInterlocutor->setNrorg($this->environment->getNrOrgTrab());
            $crmInterlocutor->setNrorginclusao($this->environment->getNrOrgTrab());
            $crmInterlocutor->setCdoperinclusao($this->environment->getCdOperador());
            $crmInterlocutor->setDtinclusao(new \DateTime());
            
            $this->entityManager->persist($crmInterlocutor);
            $this->entityManager->flush();
            
            // guarda o segquencia gerado para tabela
            $this->keys['NRSEQINTERLOCUTOR'] = $nrSeqinterlocutor;
        }
    }
    
    private function setParceria() {
        // PARCERIA
        $nrparceria = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "PARCERIA", 1, 10, false, false);
        $parceria = new \Teknisa\Model\Geral\Entities\Parceria();
        
        $parceria->setNrparceria($nrparceria);
        $parceria->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
        $parceria->setCdtipoparceiro($this->dataset['TIPODEPARCEIRO']);
        $parceria->setIdativo($this->dataset['ATIVO']);
        $parceria->setNrorg($this->environment->getNrOrgTrab());
        $parceria->setNrorginclusao($this->environment->getNrOrgTrab());
        $parceria->setCdoperinclusao($this->environment->getCdOperador());
        $parceria->setDtinclusao(new \DateTime());
        
        $this->entityManager->persist($parceria);
        $this->entityManager->flush();
        
        // guarda o segquencia gerado para tabela
        $this->keys['NRPARCERIA'] = $nrparceria;
    }
    
    private function geraEvolucao() {
        // EVOLCONT
        if ($this->dataset['IDGERAEVOLUCAO'] == 'S') {
            $nrevolcont = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "EVOLCONT", 1, 10, false, false);
            $evolcont = new \Teknisa\Model\Crm\Entities\Evolcont();
            
            $evolcont->setNrseqevolcont($nrevolcont);
            $evolcont->setNrseqcontato($this->keys['NRSEQCONTATO']);
            $evolcont->setNrcontato($this->keys['NRSEQCONTATO']);
            $evolcont->setCdprospect($this->keys['CDPROSPECT']);
            $evolcont->setDthrevolcont(\DateTime::createFromFormat('d/m/Y', $this->dataset['DTHREVOLCONT']));
            $evolcont->setCdoperevol($this->dataset['CDOPERRESPONSAVEL']);
            $evolcont->setCdtipocont($this->dataset['CDTIPOCONT']);
            $evolcont->setCdmotievocon($this->dataset['CDMOTIEVOCON']);
            $evolcont->setNrseqresulevol($this->dataset['NRSEQRESULEVOL']);
            $evolcont->setDsevolcont($this->dataset['TXEVOLCONT']);
            $evolcont->setTxevolcont($this->dataset['TXEVOLCONT']);
            $evolcont->getNrseqevolcon('01');
            $evolcont->setIdsenevocont('S');
            $evolcont->setIdtpevolcont('P');
            $evolcont->setIdageevocont('N');
            $evolcont->setIdanexoevolcont('N');
            $evolcont->setIdgerafatura('NAO');
            $evolcont->setIdativo($this->dataset['ATIVO']);
            $evolcont->setIdevolpublico();
            $evolcont->setIdrespnota();
            $evolcont->setNrorg($this->environment->getNrOrgTrab());
            $evolcont->setNrorginclusao($this->environment->getNrOrgTrab());
            $evolcont->setCdoperinclusao($this->environment->getCdOperador());
            $evolcont->setDtinclusao(new \DateTime());
            
            $this->entityManager->persist($evolcont);
            $this->entityManager->flush();
            
            // guarda o segquencia gerado para tabela
            $this->keys['NRSEQEVOLCONT'] = $nrevolcont;
            
        }
    }
    
    private function geraTarefa() {
        // FILACONTATO
        if ($this->dataset['IDGERATAREFA'] == 'S') {
            $nrfilacontato = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "FILACONTATO", 1, 10, false, false);
            $filacontato = new \Teknisa\Model\Crm\Entities\Filacontato();
            
            // define operador da tarefa, se informado no formulário sobrescreve do arquivo ou seta operador logado
            $cdoperador = null;
            if (isset($this->dataset['CDOPERREAL']) && !empty($this->dataset['CDOPERREAL']))
                $cdoperador = str_pad($this->dataset['CDOPERREAL'], 12, '0', STR_PAD_LEFT);
            else if (isset($this->dataset['COD_OPERADOR_TAREFA']) && !empty($this->dataset['COD_OPERADOR_TAREFA'])) {
                $cdoperador = str_pad($this->dataset['COD_OPERADOR_TAREFA'], 12, '0', STR_PAD_LEFT);
            } else {
                $cdoperador = $this->environment->getCdOperador();
            }
            
            $filacontato->setNrseqfilaconta($nrfilacontato);
            $filacontato->setDsfilacontato($this->dataset['DSFILACONTATO']);
            $filacontato->setDtplanfilaconta(\DateTime::createFromFormat('d/m/Y H:i', $this->dataset['DTPLANFILACONTA']));
            $filacontato->setCdoperreal($cdoperador);
            $filacontato->setNrpriorfilacont(empty($this->dataset["NRPRIORFILACONT"]) ? '' : $this->dataset["NRPRIORFILACONT"]);
            $filacontato->setNrparcnegocio($this->keys['NRPARCNEGOCIO']);
            $filacontato->setNrcontato($this->keys['NRSEQCONTATO']);
            $filacontato->setNrseqcontato($this->keys['NRSEQCONTATO']);
            $filacontato->setNrseqclassificatarefa('2');
            $filacontato->setIdativo($this->dataset['ATIVO']);
            $filacontato->setNrorg($this->environment->getNrOrgTrab());
            $filacontato->setNrorginclusao($this->environment->getNrOrgTrab());
            $filacontato->setCdoperinclusao($this->environment->getCdOperador());
            $filacontato->setDtinclusao(new \DateTime());
            
            $this->entityManager->persist($filacontato);
            $this->entityManager->flush();
            
            // guarda o segquencia gerado para tabela
            $this->keys['NRFILACONTATO'] = $nrfilacontato;
        }
    }
    
    private function validaNome() {
        $nomeParc = $this->dataset['RAZAO_SOCIAL'];
        $paramsVerifyName = array(
            "NOME"  => $nomeParc,
            "PKVALUE" => null,
            "NRORG" => $this->environment->getNrOrgTrab()
        );
        
        if(!empty($this->leadFactory->verifyLeadName($paramsVerifyName))) {
            throw new \Exception("A razão social \"{$nomeParc}\" já está vinculada a outro parceiro.");
        }
    }
    
    private function validations() {
        // INSCRICAO JURÍDICA
        $this->validaInscricaoJuridica();
        
        // RAZÃO SOCIAL
        $this->validaNome();
        
        // SEGMENTO DE MERCADO
        if (!empty($this->dataset['COD_SEGMENTO']) && $this->dataset['COD_SEGMENTO'] != '') {
            $segmercado = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Segmercado')->findOneBy(
                array(
                    'cdsegmer' => $this->dataset['COD_SEGMENTO'],
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );
            if (!is_object($segmercado))
                throw new \Exception('Código "Segmento de Mercado" não encontrado.');
        }
        
        // COMO CHEGOU ATE NOS
        if (!empty($this->dataset['COMO_CHEGOU_ATE_NOS']) && $this->dataset['COMO_CHEGOU_ATE_NOS'] != '') {
            $mododivulg = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\Mododivulg')->findOneBy(
                array(
                    'cdmododivulg' => $this->dataset['COMO_CHEGOU_ATE_NOS'],
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );
            if (!is_object($mododivulg))
                throw new \Exception('Código "Como Chegou até Nós" não encontrado.');
        }
            
        // OPERADOR TAREFA
        if ((!empty($this->dataset['COD_OPERADOR_TAREFA']) && $this->dataset['COD_OPERADOR_TAREFA'] != '')
             && !isset($this->dataset['CDOPERREAL']) && $this->dataset['IDGERATAREFA'] == 'S') {
            $operador = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Operador')->findOneBy(
                array(
                    'cdoperador' => str_pad($this->dataset['COD_OPERADOR_TAREFA'], 12, '0', STR_PAD_LEFT),
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );
            if (!is_object($operador))
                throw new \Exception('Código "Operador Tarefa" não encontrado.');
        }
        
        // MUNICIPIO
        if ((!empty($this->dataset['COD_MUNICIPIO']) && $this->dataset['COD_MUNICIPIO'] != '') &&
            !is_numeric($this->dataset['COD_MUNICIPIO'])) {
            
            $query = $this->entityManager->getConnection()->prepare("
                SELECT CDMUNICIPIO FROM MUNICIPIO WHERE UPPER(NMMUNICIPIO) = UPPER(:NMMUNICIPIO) AND UPPER(SGESTADO) = UPPER(:SGESTADO)
            ");
    
            $query->execute(array(
                    "NMMUNICIPIO" => \Teknisa\CRM\Util\Util::removeCaracteresEspeciais(trim($this->dataset['COD_MUNICIPIO'])),
                    "SGESTADO"    => trim(strtoupper($this->dataset['UF__ESTADO']))
                )
            );
            
            $return = $query->fetchAll();
            if (isset($return[0])) {
                $this->dataset['COD_MUNICIPIO'] = $return[0]['CDMUNICIPIO'];
            } else {
                $this->dataset['COD_MUNICIPIO'] = null;
            }
        }else if (!empty($this->dataset['COD_MUNICIPIO']) && $this->dataset['COD_MUNICIPIO'] != ''){
            
            $query = $this->entityManager->getConnection()->prepare("
                SELECT NMMUNICIPIO FROM MUNICIPIO WHERE CDMUNICIPIO = :CDMUNICIPIO AND UPPER(SGESTADO) = UPPER(:SGESTADO)
            ");
    
            $query->execute(array(
                    "CDMUNICIPIO" => \Teknisa\CRM\Util\Util::removeCaracteresEspeciais(trim($this->dataset['COD_MUNICIPIO'])),
                    "SGESTADO"    => trim(strtoupper($this->dataset['UF__ESTADO']))
                )
            );
            $return = $query->fetchAll();
            if (!isset($return[0])) 
                throw new \Exception('Código de Município ou UF não encontrado.');
            
        }
        
        //BAIRRO
        if ((!empty($this->dataset['BAIRRO']) && $this->dataset['BAIRRO'] != '') &&
            !is_numeric($this->dataset['BAIRRO'])) {
            
            $query = $this->entityManager->getConnection()->prepare("
                SELECT CDBAIRRO FROM BAIRRO WHERE UPPER(NMBAIRRO) = UPPER(:NMBAIRRO) AND CDMUNICIPIO = :CDMUNICIPIO AND UPPER(SGESTADO) = UPPER(:SGESTADO) AND CDPAIS = '0055'
            ");
    
            $query->execute(array(
                    "NMBAIRRO"    => $this->dataset['BAIRRO'],
                    "SGESTADO"    => trim(strtoupper($this->dataset['UF__ESTADO'])),
                    "CDMUNICIPIO" => trim(strtoupper($this->dataset['COD_MUNICIPIO']))
                )
            );
            
            $return = $query->fetchAll();
            
            if (isset($return[0])) {
                $this->dataset['NOME_BAIRRO'] =  $this->dataset['BAIRRO'];
                $this->dataset['BAIRRO'] = $return[0]['CDBAIRRO'];
            } else {
                $this->dataset['BAIRRO'] = null;
                $this->dataset['NOME_BAIRRO'] =  null;
            }
        }else if (!empty($this->dataset['BAIRRO']) && $this->dataset['BAIRRO'] != ''){
            
            $query = $this->entityManager->getConnection()->prepare("
                SELECT NMBAIRRO FROM BAIRRO WHERE CDBAIRRO = :CDBAIRRO AND UPPER(SGESTADO) = UPPER(:SGESTADO) AND CDMUNICIPIO = :CDMUNICIPIO
            ");
    
            $query->execute(array(
                    "CDBAIRRO"    => \Teknisa\CRM\Util\Util::removeCaracteresEspeciais(trim($this->dataset['BAIRRO'])),
                    "SGESTADO"    => trim(strtoupper($this->dataset['UF__ESTADO__INTERLOCUTOR'])),
                    "CDMUNICIPIO" => trim(strtoupper($this->dataset['COD_MUNICIPIO__INTERLOCUTOR']))
                )
            );
            $return = $query->fetchAll();
            if (!isset($return[0])) 
                throw new \Exception('Código de Bairro não encontrado.');
            else 
                $this->dataset['NOME_BAIRRO'] =  $return[0]['NMBAIRRO'];
        } else {
            $this->dataset['BAIRRO']      = null;
            $this->dataset['NOME_BAIRRO'] =  null;
        }
        
        // ATIVO
        if (!empty($this->dataset['ATIVO']) && $this->dataset['ATIVO'] != '') {
            if($this->dataset['ATIVO'] != 'S' && $this->dataset['ATIVO'] != 'N')
                $this->dataset['ATIVO'] = 'S';
        }else{
            $this->dataset['ATIVO'] = 'S';
        }
        
        //DATA NASCIMENTO/FUNDAÇÃO
        if(!empty($this->dataset['DATA_DE_NASCIMENTO/FUNDACAO'])){
            if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $this->dataset['DATA_DE_NASCIMENTO/FUNDACAO'])) {
                throw new \Exception("Data de Nascimento/Fundação em formato inválido");
            }
        }
        
        //DATA DE INÍCIO RELACIONAMENTO
        if(!empty($this->dataset['DATA_DE_INICIO_RELACIONAMENTO'])){
            if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $this->dataset['DATA_DE_INICIO_RELACIONAMENTO'])) {
                throw new \Exception("Data de Início de Relacionamento em formato inválido");
            }
        }
        
        /*Interlocutor*/
        
        // RECEBE PRESENTE
        if (!empty($this->dataset['RECEBE_PRESENTE']) && $this->dataset['RECEBE_PRESENTE'] != '') {
            if($this->dataset['RECEBE_PRESENTE'] != 'S' && $this->dataset['RECEBE_PRESENTE'] != 'N')
                $this->dataset['RECEBE_PRESENTE'] = 'N';
        }else{
            $this->dataset['RECEBE_PRESENTE'] = 'N';
        }
        
        //MUNICIPIO
        if ((!empty($this->dataset['COD_MUNICIPIO__INTERLOCUTOR']) && $this->dataset['COD_MUNICIPIO__INTERLOCUTOR'] != '') &&
            !is_numeric($this->dataset['COD_MUNICIPIO__INTERLOCUTOR'])) {
            
            $query = $this->entityManager->getConnection()->prepare("
                SELECT CDMUNICIPIO FROM MUNICIPIO WHERE UPPER(NMMUNICIPIO) = UPPER(:NMMUNICIPIO) AND UPPER(SGESTADO) = UPPER(:SGESTADO)
            ");
    
            $query->execute(array(
                    "NMMUNICIPIO" => \Teknisa\CRM\Util\Util::removeCaracteresEspeciais(trim($this->dataset['COD_MUNICIPIO__INTERLOCUTOR'])),
                    "SGESTADO"    => trim(strtoupper($this->dataset['UF__ESTADO__INTERLOCUTOR']))
                )
            );
            
            $return = $query->fetchAll();
            if (isset($return[0])) {
                $this->dataset['COD_MUNICIPIO__INTERLOCUTOR'] = $return[0]['CDMUNICIPIO'];
            } else {
                $this->dataset['COD_MUNICIPIO__INTERLOCUTOR'] = null;
            }
        }else if (!empty($this->dataset['COD_MUNICIPIO__INTERLOCUTOR']) && $this->dataset['COD_MUNICIPIO__INTERLOCUTOR'] != ''){
            
            $query = $this->entityManager->getConnection()->prepare("
                SELECT NMMUNICIPIO FROM MUNICIPIO WHERE CDMUNICIPIO = :CDMUNICIPIO AND UPPER(SGESTADO) = UPPER(:SGESTADO)
            ");
    
            $query->execute(array(
                    "CDMUNICIPIO" => \Teknisa\CRM\Util\Util::removeCaracteresEspeciais(trim($this->dataset['COD_MUNICIPIO__INTERLOCUTOR'])),
                    "SGESTADO"    => trim(strtoupper($this->dataset['UF__ESTADO__INTERLOCUTOR']))
                )
            );
            $return = $query->fetchAll();
            if (!isset($return[0])) 
                throw new \Exception('Código de Município do Interlocutor não encontrado.');
            
        }
        
        //BAIRRO
        if ((!empty($this->dataset['BAIRRO__INTERLOCUTOR']) && $this->dataset['BAIRRO__INTERLOCUTOR'] != '') &&
            !is_numeric($this->dataset['BAIRRO__INTERLOCUTOR'])) {
            
            $query = $this->entityManager->getConnection()->prepare("
                SELECT CDBAIRRO FROM BAIRRO WHERE UPPER(NMBAIRRO) = UPPER(:NMBAIRRO) AND CDMUNICIPIO = :CDMUNICIPIO AND UPPER(SGESTADO) = UPPER(:SGESTADO) AND CDPAIS = '0055'
            ");
    
            $query->execute(array(
                    "NMBAIRRO"    => $this->dataset['BAIRRO__INTERLOCUTOR'],
                    "SGESTADO"    => trim(strtoupper($this->dataset['UF__ESTADO__INTERLOCUTOR'])),
                    "CDMUNICIPIO" => trim(strtoupper($this->dataset['COD_MUNICIPIO__INTERLOCUTOR']))
                )
            );
            
            $return = $query->fetchAll();
            if (isset($return[0])) {
                $this->dataset['NOME_BAIRRO__INTERLOCUTOR'] = $this->dataset['BAIRRO__INTERLOCUTOR'];
                $this->dataset['BAIRRO__INTERLOCUTOR'] = $return[0]['CDBAIRRO'];
            } else {
                $this->dataset['BAIRRO__INTERLOCUTOR'] = null;
                $this->dataset['NOME_BAIRRO__INTERLOCUTOR'] = null;
            }
        }else if (!empty($this->dataset['BAIRRO__INTERLOCUTOR']) && $this->dataset['BAIRRO__INTERLOCUTOR'] != ''){
            
            $query = $this->entityManager->getConnection()->prepare("
                SELECT NMBAIRRO FROM BAIRRO WHERE CDBAIRRO = :CDBAIRRO AND UPPER(SGESTADO) = UPPER(:SGESTADO) AND CDMUNICIPIO = :CDMUNICIPIO
            ");
    
            $query->execute(array(
                    "CDBAIRRO"    => \Teknisa\CRM\Util\Util::removeCaracteresEspeciais(trim($this->dataset['BAIRRO__INTERLOCUTOR'])),
                    "SGESTADO"    => trim(strtoupper($this->dataset['UF__ESTADO__INTERLOCUTOR'])),
                    "CDMUNICIPIO" => trim(strtoupper($this->dataset['COD_MUNICIPIO__INTERLOCUTOR']))
                )
            );
            $return = $query->fetchAll();
            if (!isset($return[0])) 
                throw new \Exception('Código de Bairro do Interlocutor não encontrado.');
            else
                $this->dataset['NOME_BAIRRO'] =  $return[0]['NMBAIRRO'];
            
        }
        
        //CARGO
        if (!empty($this->dataset['CARGO']) && $this->dataset['CARGO'] != '' && is_numeric($this->dataset['CARGO'])) {
            $mododivulg = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Cargointerloc')->findOneBy(
                array(
                    'cdcargointerloc' => str_pad($this->dataset['CARGO'], 5, 0, STR_PAD_LEFT),
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );
            if (!is_object($mododivulg))
                throw new \Exception('Código "Cargo" não encontrado.');
        }else if(!empty($this->dataset['CARGO']) && $this->dataset['CARGO'] != ''){
            $query = $this->entityManager->getConnection()->prepare("
                    SELECT CDCARGOINTERLOC FROM CARGOINTERLOC WHERE NMCARGOINTERLOC LIKE (:CARGO)
                ");
    
            $query->execute(array(
                    "CARGO"       => \Teknisa\CRM\Util\Util::removeCaracteresEspeciais(trim($this->dataset['CARGO']))
                )
            );
            $return = $query->fetchAll();
            if (isset($return[0])) 
                $this->dataset['CARGO'] =  $return[0]['CDCARGOINTERLOC'];
            else 
                $this->dataset['CARGO'] =  null;
        } else {
            $this->dataset['CARGO']      = null;
        }
        
        //Validação tamanho campos de descrição
        $this->dataset['RAZAO_SOCIAL']                 = substr($this->dataset['RAZAO_SOCIAL'], 0, 250); 
        $this->dataset['NOME_FANTASIA']                = substr($this->dataset['NOME_FANTASIA'], 0, 250);
        $this->dataset['BAIRRO']                       = substr($this->dataset['BAIRRO'], 0, 100);
        $this->dataset['COMPLEMENTO']                  = substr($this->dataset['COMPLEMENTO'], 0, 100);
        $this->dataset['ENDERECO']                     = substr($this->dataset['ENDERECO'], 0, 250); 
        $this->dataset['TELEFONE']                     = substr($this->dataset['TELEFONE'], 0, 25); 
        $this->dataset['TELEFONE_2']                   = substr($this->dataset['TELEFONE_2'], 0, 25); 
        $this->dataset['EMAIL']                        = substr($this->dataset['EMAIL'], 0, 50); 
        $this->dataset['NOME_INTERLOCUTOR']            = substr($this->dataset['NOME_INTERLOCUTOR'], 0, 50); 
        $this->dataset['NOME_DO_RESPONSAVEL_GERAL']    = substr($this->dataset['NOME_DO_RESPONSAVEL_GERAL'], 0, 100); 
        $this->dataset['NOME_DO_PONTO_DE_ATENDIMENTO'] = substr($this->dataset['NOME_DO_PONTO_DE_ATENDIMENTO'], 0, 100); 
        $this->dataset['NUMERO_DE_INTEGRACAO']         = substr($this->dataset['NUMERO_DE_INTEGRACAO'], 0, 20);      
        $this->dataset['TELEFONE__INTERLOCUTOR']       = substr($this->dataset['TELEFONE__INTERLOCUTOR'], 0, 20);
        $this->dataset['EMAIL__INTERLOCUTOR']          = substr($this->dataset['EMAIL__INTERLOCUTOR'], 0, 70);
        $this->dataset['ENDERECO__INTERLOCUTOR']       = substr($this->dataset['ENDERECO__INTERLOCUTOR'], 0, 50);
        $this->dataset['COMPLEMENTO__INTERLOCUTOR' ]   = substr($this->dataset['COMPLEMENTO__INTERLOCUTOR'], 0, 20);
        
        
        
        if ($this->dataset['IDGERATAREFA'] == 'S') 
            $this->dataset['DSFILACONTATO'] = substr($this->dataset['DSFILACONTATO'], 0, 2000);
            
        if ($this->dataset['IDGERAEVOLUCAO'] == 'S') 
            $this->dataset['TXEVOLCONT']    = substr($this->dataset['TXEVOLCONT'], 0, 2000);
        
        //Remove os espaços
        foreach ($this->dataset as $key => $value) {
            if(is_string($value))
                $this->dataset[$key] = trim($value);
        }
    }
    
    private function validaInscricaoJuridica() {
        if (empty($this->dataset['CNPJ']) || $this->dataset['CNPJ'] == '') {
            throw new \Exception('Campo Obrigatório: CNPJ.');
        } else {
            $inscricaoJuridica = Util::getSomenteNumeros($this->dataset['CNPJ']);
            $lengthInscricao   = strlen($inscricaoJuridica);
            
            if ($lengthInscricao < 11) {
                $this->dataset['CNPJ'] = str_pad($inscricaoJuridica, 11, 0, STR_PAD_LEFT);
            } else if ($lengthInscricao > 11 && $lengthInscricao < 14) {
                $this->dataset['CNPJ'] = str_pad($inscricaoJuridica, 14, 0, STR_PAD_LEFT);
            }
            
            $paramsVerifyInsc = array(
                "INSCRICAO"  => $inscricaoJuridica,
                "PKVALUE" => null,
                "NRORG" => $this->environment->getNrOrgTrab()
            );
            if(!empty($this->leadFactory->verifyLeadInsc($paramsVerifyInsc))) {
                throw new \Exception("A Inscrição \"{$inscricaoJuridica}\" já está vinculada a outro parceiro.");
            }
        }
    }
    
    //Verifica se algo relacionado ao endereço do Prospect foi preenchido.
    private function verificaCamposEndereco($dataset) {
        $endereco = array();
        $enderecoHeaders = array("UF__ESTADO" => '', "COD_MUNICIPIO" => '', "ENDERECO" => '', "NUMERO" => '', "COMPLEMENTO" => '', "BAIRRO" => '', "CEP" => '');
        foreach ($dataset as $header => $value) {
            if(\Zeedhi\Framework\Util\Functions::arrayKeyExists($header, $enderecoHeaders)){
                if(!empty($value))
                    array_push($endereco, $value);        
            }
        }
        return $endereco;
    }
    
    private function defineOperadorResponsavel() {
        // define operador da tarefa, se informado no formulário sobrescreve do arquivo ou seta operador logado
        $cdoperador = null;
        if (isset($this->dataset['CDOPERREAL']) && !empty($this->dataset['CDOPERREAL']))
            $cdoperador = str_pad($this->dataset['CDOPERREAL'], 12, '0', STR_PAD_LEFT);
        else if (isset($this->dataset['COD_OPERADOR_TAREFA']) && !empty($this->dataset['COD_OPERADOR_TAREFA'])) {
            $cdoperador = str_pad($this->dataset['COD_OPERADOR_TAREFA'], 12, '0', STR_PAD_LEFT);
        } else {
            $cdoperador = $this->environment->getCdOperador();
        }
    }
    
    //Seta a connection baseado na organização, seta o dataset com os dados do lead do RD
    public function setConnectionAndDataSet($dataset, $entityManager, $org){
        $this->entityManager = $entityManager;
        $this->environment->setNrOrgTrab($org);
        $this->environment->setCdOperador(empty($dataset['CDOPERRESPONSAVEL']) ? 1 : $dataset['CDOPERRESPONSAVEL']);
        $this->setDataset($dataset);
        $this->keys['CDPROSPECT'] = null;
    }
    
    public function importLeadRDStation(){
        //Limpa o CNPJ, havia sido setado como '99999999999999' para passar na validação
        $this->dataset['CNPJ'] = '';
        $this->setLead();
        $this->geraEvolucao();
        $this->geraTarefa();
        
        $this->salvaInterlocutorEvolucao();
        $this->salvaInterlocutorTarefa();
        
        return $this->keys['NRPARCNEGOCIO'];
    }
    
    public function evoluiLeadRDStation($lead){
        $this->keys['NRSEQCONTATO']  = $lead['NRSEQCONTATO'];
        $this->keys['NRPARCNEGOCIO'] = $lead['NRPARCNEGOCIO'];
        $this->geraEvolucao();
        $this->geraTarefa();
        
        $this->salvaInterlocutorEvolucao();
        $this->salvaInterlocutorTarefa();
        $this->updateStatusLead();
    }
    
    //Seta o interlocutor da nova evolução criada para o lead vindo do RDStation
    private function salvaInterlocutorEvolucao(){
        $interlocutor = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\CrmInterlocutor')->findOneBy(
            array(
                'emailinterloc' => $this->dataset['EMAIL__INTERLOCUTOR'],
                'nrparcnegocio' => $this->keys['NRPARCNEGOCIO'],
                'nrorg' => $this->environment->getNrOrgTrab()
            )
        );
        $nrseqinterlocutor = $interlocutor->getNrseqinterlocutor();
        
        $evolcont = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\Evolcont')->findOneBy(
            array(
                'nrseqevolcont' => $this->keys['NRSEQEVOLCONT'],
                'nrorg' => $this->environment->getNrOrgTrab()
            )
        );
        
        $evolcont->setNrseqinterlocutor($nrseqinterlocutor);
        
        $this->entityManager->persist($evolcont);
        $this->entityManager->flush();
    }
    
    //Seta o interlocutor da nova tarefa criada para o lead vindo do RDStation
    private function salvaInterlocutorTarefa(){
        $interlocutor = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\CrmInterlocutor')->findOneBy(
            array(
                'emailinterloc' => $this->dataset['EMAIL__INTERLOCUTOR'],
                'nrparcnegocio' => $this->keys['NRPARCNEGOCIO'],
                'nrorg' => $this->environment->getNrOrgTrab()
            )
        );
        $nrseqinterlocutor = $interlocutor->getNrseqinterlocutor();
        
        $filacontato = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\Filacontato')->findOneBy(
            array(
                'nrseqfilaconta' => $this->keys['NRFILACONTATO'],
                'nrorg' => $this->environment->getNrOrgTrab()
            )
        );
        
        $filacontato->setNrseqinterlocutor($nrseqinterlocutor);
        $filacontato->setDstelefonetarefa($this->dataset['TELEFONE__INTERLOCUTOR']);
        $filacontato->setDsemailtarefa($this->dataset['EMAIL__INTERLOCUTOR']);
        
        $this->entityManager->persist($filacontato);
        $this->entityManager->flush();
    }
    
    //Seta o status do lead('3'  = 'Qualidficado'  |  '4' = 'Desqualificado')
    private function updateStatusLead(){
        $lead = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\CrmCandidato')->findOneBy(
            array(
                'nrparcnegocio' => $this->keys['NRPARCNEGOCIO'],
                'nrorg' => $this->environment->getNrOrgTrab()
            )
        );
        
        $lead->setIdstatuscan(!empty($this->dataset['IDSTATUSCAN']) && isset($this->dataset['IDSTATUSCAN']) ? $this->dataset['IDSTATUSCAN'] : '2');
        
        $this->entityManager->persist($lead);
        $this->entityManager->flush();
    }
}