<?php
namespace Teknisa\CRM\Service;


class MapService {
    
    protected $mapFactory;
    
    public function __construct ($mapFactory){
        
        $this->mapFactory    = $mapFactory;
    }
    
    public function getLocationsForMap($parameters, $filters){
        return $this->mapFactory->getLocationsForMap($parameters, $filters);
    }
    
    public function geocodePartners($partners){
        
        $errors = array();
        $index = 0;
        foreach($partners as $partner){
            
            try {
                $paramsToInsertLocation = array(
                    "DSLATITUDE"     => $partner['lat'],
                    "DSLONGITUDE"    => $partner['lng'],
                    "NRORG"          => $partner['nrorg'],
                    "NRPARCNEGOCIO"  => $partner['parcnegocio']
                );
                $this->mapFactory->insertLocation($paramsToInsertLocation);
            }catch(\Exception $e){
                $errors[$index]['NRPARCNEGOCIO'] = $partner['parcnegocio'];
            }
            
            $index++;
        }
        
        if (empty($errors))
            return true;
        else
            return array("error" => $errors);
            
    }
    
    public function getFilterPlaceHolder($filters) {
        $conditions = array();
        
        foreach($filters as $value) {
            if($value["operator"] === 'LIKE' || $value["operator"] === '=')
                $conditions[] = "UPPER(" . $value["columnName"] . ") " . $value["operator"] . " UPPER('" . $value["value"] . "')";
            else if($value["operator"] === 'BETWEEN' && $value["type"] === 'date')
                $conditions[] = "UPPER(" . $value["columnName"] . ") " . $value["operator"] . " TO_DATE('" . $value["value"][0] . "') AND TO_DATE('" . $value["value"][1] . "')" ;
                else if($value["operator"] === 'BETWEEN' && $value["type"] === 'number')
                $conditions[] = "UPPER(" . $value["columnName"] . ") " . $value["operator"] . " '" . $value["value"][0] . "' AND '" . $value["value"][1] . "'" ;
            else if($value["operator"] === 'IN')
                $conditions[] = "UPPER(" . $value["columnName"] . ") " . $value["operator"] . "(" . implode(", ", $value["value"]) . ")";
        }

        if (empty($conditions)) {
            $conditions[] = "1 = 1";
        }
        
        return implode(" AND ", $conditions);
    }
    
    public function atualizaLatLong($parceiro, $nrorg) {
        $params = array(
            "DSLONGITUDE"    => $parceiro['DSLONGITUDE'],
            "DSLATITUDE"     => $parceiro['DSLATITUDE'],
            "NRORG"          => $nrorg,
            "NRPARCNEGOCIO"  => $parceiro['NRPARCNEGOCIO']
        );
        
        $this->mapFactory->insertLocation($params);
    }
}