/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: VERIFICA_RESTRICOES_CONTRATUAIS.SQL

Descrio:
Retorna a filial e os servicos que possuem restries contratuais referente ao cardapio

@C:\Web_605\Sql\End_Conv\Oracle\0322_PLAFUNO_VERIFICA_RESTRICOES_CONTRATUAIS.SQL

Criao:
28/12/2017 - Cristiane Faria

P_NRLISTA -> Lista de filiais/servios a serem verificados
P_VERRESTR -> DETERMINA SE A RESTRICAO SERA VERIFICADA INDEPENDENTE DO PARAMETRO NA PARAMPLANEJA
P_CDFILIAL -> FILIAL ESPECIFICADA
P_CDSERVFILI -> SERVICO ESPECIFICADO-> OU PASSA P_NRLISTA OU P_CDFILIAL E P_CDSERVFILI
Manutenes:
__/__/____ - _______ ___________
*/


IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'RESTR_CONTRATUAIS_CARD'
             AND TYPE = 'TF'
             AND U.UID = O.UID
             AND U.NAME = USER)
DROP FUNCTION RESTR_CONTRATUAIS_CARD
GO

CREATE FUNCTION RESTR_CONTRATUAIS_CARD
(  @P_CDFILIAL     VARCHAR(4),
   @P_CDSERVFILI   VARCHAR(5),
   @P_NRLISTA      VARCHAR(2000),
   @P_DTINICIAL    DATE,
   @P_DTFINAL      DATE,
   @P_VERRESTR     VARCHAR(1) = 'S')
returns @RESTR_CONTRATUAIS_CARD_TABLE table
(CDFILIAL         VARCHAR(4),
 CDSERVFILI       VARCHAR(5))
AS
BEGIN
   DECLARE @V_RESTRICAO          INT;
   DECLARE @V_IDRESTRAPROVCARD   VARCHAR(1);
   DECLARE @V_CDFILIAL           VARCHAR(4);
   DECLARE @V_CDSERVFILI         VARCHAR(5);

   SET @V_RESTRICAO = 0;
   SET @V_IDRESTRAPROVCARD = 'N';   

   DECLARE CUR_FILIAL CURSOR FOR
      (SELECT CDFILIAL, CDSERVFILI
         FROM LISTA_SERVICO
        WHERE NRLISTA = @P_NRLISTA
       UNION
       SELECT CDFILIAL, CDSERVFILI
         FROM SERVICO
        WHERE CDFILIAL   = @P_CDFILIAL
          AND CDSERVFILI = @P_CDSERVFILI);
   OPEN CUR_FILIAL;
   FETCH NEXT FROM CUR_FILIAL INTO @V_CDFILIAL, @V_CDSERVFILI;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
       SELECT @V_IDRESTRAPROVCARD = ISNULL(IDRESTRAPROVCARD,'N')
         FROM PARAMPLANEJA
        WHERE CDFILIAL = @V_CDFILIAL;

      IF (@V_IDRESTRAPROVCARD = 'S') OR (@P_VERRESTR = 'S') BEGIN
         /*Frequncia de Pratos no Ms*/
         IF (@V_RESTRICAO = 0) BEGIN
            SELECT  @V_RESTRICAO = SUM(RESTRICAO)
              FROM (
                  SELECT FP.CDFILIAL,
                         FP.CDSERVFILI,
                         FP.CDPRATO,
                         CONVERT(DOUBLE PRECISION, FP.NRMAXIFREPRA) AS NRMAXIFREPRA,
                         PR.NMPRATO,
                         RIGHT(REPLICATE('0', 2) + DATEPART(WK, CA.DTCARDAPIO), 2) AS NRSEMANA,
                         CONVERT(DOUBLE PRECISION, COUNT(*)) AS RESTRICAO
                    FROM FREQPRAT FP,
                         COMPCARD CC,
                         CARDADIA CA,
                         CNFCAMES CM,
                         PRATO PR
                   WHERE
                     (FP.CDFILIAL     = @V_CDFILIAL)              AND
                     (FP.CDSERVFILI   = @V_CDSERVFILI)            AND
                     (CA.CDFILIAL     = @V_CDFILIAL)              AND
                     (CA.CDSERVFILI   = @V_CDSERVFILI)            AND
                     (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)    AND
                     (CC.CDFILIAL     = @V_CDFILIAL)                        AND
                     (CC.NRCARDAPIO   = CA.NRCARDAPIO)                      AND
                     (CHARINDEX(CONVERT(VARCHAR, FP.CDPRATO), CONVERT(VARCHAR, CC.CDPRATO)) = 1) AND
                     (CM.CDFILIAL     = @V_CDFILIAL)                        AND
                     (CM.CDSERVFILI   = @V_CDSERVFILI)                      AND
                     (CM.DTREFECNFMES = CA.DTMESCARD)                      AND
                     (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                   AND
                     (CM.IDOPCCNFMES  = 'N')                               AND
                     (PR.CDFILAUXPRAT = FP.CDFILAUXPRAT)                   AND
                     (PR.CDPRATO      = FP.CDPRATO)
                   GROUP BY
                      FP.CDFILIAL,
                      FP.CDSERVFILI,
                      FP.CDPRATO,
                      FP.NRMAXIFREPRA,
                      PR.NMPRATO,
                      CA.DTCARDAPIO
                  HAVING
                     (COUNT(*) > FP.NRMAXIFREPRA)
                     ) RESTRICAO;

            IF @V_RESTRICAO > 0 BEGIN
               INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
               (CDFILIAL, CDSERVFILI)
                VALUES (@V_CDFILIAL, @V_CDSERVFILI);
            END
            ELSE BEGIN
               SET @V_RESTRICAO = 0;
            END;

            IF @V_RESTRICAO = 0 BEGIN
               /*Frequncia de Pratos no Ms, verificando o minimo e o maximo por prato*/
               SELECT @V_RESTRICAO = SUM(RESTRICAO)
                 FROM (
                     SELECT FP.CDFILIAL,
                            FP.CDSERVFILI,
                            FP.CDPRATO,
                            CONVERT(DOUBLE PRECISION, FP.NRMINIFREPRA) AS NRMINIFREPRA,
                            CONVERT(DOUBLE PRECISION, FP.NRMAXMESFPRA) AS NRMAXMESFPRA,
                            PR.NMPRATO,
                            CA.DTMESCARD,
                            CONVERT(DOUBLE PRECISION, COUNT(*)) AS RESTRICAO
                     FROM FREQPRAT FP,
                          COMPCARD CC,
                          CARDADIA CA,
                          CNFCAMES CM,
                          PRATO PR
                    WHERE
                        (FP.CDFILIAL     = @V_CDFILIAL)               AND
                        (FP.CDSERVFILI   = @V_CDSERVFILI)             AND
                        (CA.CDFILIAL     = @V_CDFILIAL)               AND
                        (CA.CDSERVFILI   = @V_CDSERVFILI)             AND
                        (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)     AND
                        (CC.CDFILIAL     = @V_CDFILIAL)               AND
                        (CC.NRCARDAPIO   = CA.NRCARDAPIO)            AND
                        (CHARINDEX(FP.CDPRATO, CC.CDPRATO) =1)                AND
                        (CM.CDFILIAL     = @V_CDFILIAL)               AND
                        (CM.CDSERVFILI   = @V_CDSERVFILI)             AND
                        (CM.DTREFECNFMES = CA.DTMESCARD)             AND
                        (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)          AND
                        (CM.IDOPCCNFMES  = 'N')                      AND
                        (PR.CDFILAUXPRAT = FP.CDFILAUXPRAT)          AND
                        (PR.CDPRATO      = FP.CDPRATO)
                    GROUP BY
                           FP.CDFILIAL,
                           FP.CDSERVFILI,
                           FP.CDPRATO,
                           FP.NRMINIFREPRA,
                           FP.NRMAXMESFPRA,
                           PR.NMPRATO,
                           CA.DTMESCARD
                    HAVING (COUNT(*) < FP.NRMINIFREPRA) OR (COUNT(*) > FP.NRMAXMESFPRA)
                    ) RESTRICAO;

               IF @V_RESTRICAO > 0 BEGIN
                  INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
                  (CDFILIAL, CDSERVFILI)
                   VALUES (@V_CDFILIAL, @V_CDSERVFILI);
               END
               ELSE BEGIN
                  SET @V_RESTRICAO = 0;
               END;

            END;
         END;

         /*Frequncia de Opes no Ms*/
         IF (@V_RESTRICAO = 0) BEGIN
            SELECT @V_RESTRICAO = SUM(RESTRICAO)
              FROM (
                  SELECT FO.CDFILIAL,
                         FO.CDSERVFILI,
                         FO.CDPRATO,
                         CONVERT(DOUBLE PRECISION, FO.NRMAXIFREOPC) AS NRMAXIFREOPC,
                         PR.NMPRATO,
                         RIGHT(REPLICATE('0', 2) + DATEPART(WK, CA.DTCARDAPIO), 2) AS NRSEMANA,
                         CONVERT(DOUBLE PRECISION, COUNT(*)) AS RESTRICAO
                    FROM FREQOPCA FO,
                         COMPCARD CC,
                         CARDADIA CA,
                         CNFCAMES CM,
                         PRATO PR
                  WHERE
                     (FO.CDFILIAL     = @V_CDFILIAL)            AND
                     (FO.CDSERVFILI   = @V_CDSERVFILI)          AND
                     (CA.CDFILIAL     = @V_CDFILIAL)            AND
                     (CA.CDSERVFILI   = @V_CDSERVFILI)          AND
                     (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)  AND
                     (CC.CDFILIAL     = @V_CDFILIAL)            AND
                     (CC.NRCARDAPIO   = CA.NRCARDAPIO)         AND
                     (CHARINDEX(FO.CDPRATO, CC.CDPRATO) = 1)               AND
                     (CM.CDFILIAL     = @V_CDFILIAL)            AND
                     (CM.CDSERVFILI   = @V_CDSERVFILI)          AND
                     (CM.DTREFECNFMES = CA.DTMESCARD)          AND
                     (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)       AND
                     (CM.IDOPCCNFMES  = 'S')                   AND
                     (PR.CDFILAUXPRAT = FO.CDFILAUXPRAT)       AND
                     (PR.CDPRATO      = FO.CDPRATO)
                  GROUP BY
                     FO.CDFILIAL,
                     FO.CDSERVFILI,
                     FO.CDPRATO,
                     FO.NRMAXIFREOPC,
                     PR.NMPRATO,
                     CA.DTCARDAPIO
                  HAVING
                     (COUNT(*) > FO.NRMAXIFREOPC)
                  ) RESTRICAO;

            IF @V_RESTRICAO > 0 BEGIN
               INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
               (CDFILIAL, CDSERVFILI)
                VALUES (@V_CDFILIAL, @V_CDSERVFILI);
            END
            ELSE BEGIN
               SET @V_RESTRICAO = 0;
            END;

            IF @V_RESTRICAO = 0 BEGIN
               /*Frequncia de Opes no Ms, verificando o minimo e o maximo*/
               SELECT @V_RESTRICAO = SUM(RESTRICAO)
                 FROM (
                     SELECT FO.CDFILIAL,
                            FO.CDSERVFILI,
                            FO.CDPRATO,
                            CONVERT(DOUBLE PRECISION, FO.NRMINIFREOPC) AS NRMINIFREOPC,
                            CONVERT(DOUBLE PRECISION, FO.NRMAXMESFOPC) AS NRMAXMESFOPC,
                            PR.NMPRATO,
                            CA.DTMESCARD,
                            CONVERT(DOUBLE PRECISION, COUNT(*)) AS RESTRICAO
                     FROM
                        FREQOPCA FO,
                        COMPCARD CC,
                        CARDADIA CA,
                        CNFCAMES CM,
                        PRATO PR
                     WHERE
                        (FO.CDFILIAL     = @V_CDFILIAL)              AND
                        (FO.CDSERVFILI   = @V_CDSERVFILI)            AND
                        (CA.CDFILIAL     = @V_CDFILIAL)              AND
                        (CA.CDSERVFILI   = @V_CDSERVFILI)            AND
                        (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)    AND
                        (CC.CDFILIAL     = @V_CDFILIAL)              AND
                        (CC.NRCARDAPIO   = CA.NRCARDAPIO)           AND
                        (CHARINDEX(FO.CDPRATO, CC.CDPRATO) = 1)               AND
                        (CM.CDFILIAL     = @V_CDFILIAL)              AND
                        (CM.CDSERVFILI   = @V_CDSERVFILI)            AND
                        (CM.DTREFECNFMES = CA.DTMESCARD)            AND
                        (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)         AND
                        (CM.IDOPCCNFMES  = 'S')                     AND
                        (PR.CDFILAUXPRAT = FO.CDFILAUXPRAT)         AND
                        (PR.CDPRATO      = FO.CDPRATO)
                     GROUP BY
                        FO.CDFILIAL,
                        FO.CDSERVFILI,
                        FO.CDPRATO,
                        FO.NRMINIFREOPC,
                        FO.NRMAXMESFOPC,
                        PR.NMPRATO,
                        CA.DTMESCARD
                     HAVING
                        (COUNT(*) < FO.NRMINIFREOPC) OR (COUNT(*) > FO.NRMAXMESFOPC)
                     ) RESTRICAO;

               IF @V_RESTRICAO > 0 BEGIN
                  INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
                  (CDFILIAL, CDSERVFILI)
                   VALUES (@V_CDFILIAL, @V_CDSERVFILI);
               END
               ELSE BEGIN
                  SET @V_RESTRICAO = 0;
               END;

            END;
         END;

         /*Restrio de Pratos no Ms*/
         IF (@V_RESTRICAO = 0) BEGIN
            SELECT @V_RESTRICAO = SUM(RESTRICAO)
              FROM (
              SELECT
                  RP.CDFILIAL,
                  RP.CDSERVFILI,
                  RP.CDPRATO,
                  PR.NMPRATO,
                  CA.DTMESCARD,
                  CONVERT(DOUBLE PRECISION, COUNT(*)) AS RESTRICAO
               FROM RESTPRAT RP,
                    COMPCARD CC,
                    CARDADIA CA,
                    CNFCAMES CM,
                    PRATO PR
               WHERE
                  (RP.CDFILIAL     = @V_CDFILIAL)            AND
                  (RP.CDSERVFILI   = @V_CDSERVFILI)          AND
                  (CA.CDFILIAL     = @V_CDFILIAL)            AND
                  (CA.CDSERVFILI   = @V_CDSERVFILI)          AND
                  (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)  AND
                  (CC.CDFILIAL     = @V_CDFILIAL)                     AND
                  (CC.NRCARDAPIO   = CA.NRCARDAPIO)                  AND
                  (CHARINDEX(RP.CDPRATO, CC.CDPRATO) = 1)               AND
                  (CM.CDFILIAL     = @V_CDFILIAL)                     AND
                  (CM.CDSERVFILI   = @V_CDSERVFILI)                   AND
                  (CM.DTREFECNFMES = CA.DTMESCARD)                   AND
                  (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                AND
                  (CM.IDOPCCNFMES  = 'N')                            AND
                  (PR.CDFILAUXPRAT = RP.CDFILAUXPRAT)                AND
                  (PR.CDPRATO      = RP.CDPRATO)
               GROUP BY
                  RP.CDFILIAL,
                  RP.CDSERVFILI,
                  RP.CDPRATO,
                  PR.NMPRATO,
                  CA.DTMESCARD) RESTRICAO;

            IF @V_RESTRICAO > 0 BEGIN
               INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
               (CDFILIAL, CDSERVFILI)
                VALUES (@V_CDFILIAL, @V_CDSERVFILI);
            END
            ELSE BEGIN
               SET @V_RESTRICAO = 0;
            END;

         END;

         /*Restrio de Opces no Ms*/
         IF (@V_RESTRICAO = 0) BEGIN
            SELECT @V_RESTRICAO = SUM(RESTRICAO)
              FROM (
                 SELECT
                     RO.CDFILIAL,
                     RO.CDSERVFILI,
                     RO.CDPRATO,
                     PR.NMPRATO,
                     CA.DTMESCARD,
                     CONVERT(DOUBLE PRECISION, COUNT(*)) AS RESTRICAO
                 FROM RESTOPCA RO,
                   COMPCARD CC,
                   CARDADIA CA,
                   CNFCAMES CM,
                   PRATO PR
                WHERE
                  (RO.CDFILIAL     = @V_CDFILIAL)               AND
                  (RO.CDSERVFILI   = @V_CDSERVFILI)             AND
                  (CA.CDFILIAL     = @V_CDFILIAL)               AND
                  (CA.CDSERVFILI   = @V_CDSERVFILI)             AND
                  (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)   AND
                  (CC.CDFILIAL     = @V_CDFILIAL)                      AND
                  (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
                  (CHARINDEX(RO.CDPRATO, CC.CDPRATO) = 1)               AND
                  (CM.CDFILIAL     = @V_CDFILIAL)                      AND
                  (CM.CDSERVFILI   = @V_CDSERVFILI)                    AND
                  (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
                  (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
                  (CM.IDOPCCNFMES  = 'S')                             AND
                  (PR.CDFILAUXPRAT = RO.CDFILAUXPRAT)                 AND
                  (PR.CDPRATO      = RO.CDPRATO)
                GROUP BY
                  RO.CDFILIAL,
                  RO.CDSERVFILI,
                  RO.CDPRATO,
                  PR.NMPRATO,
                  CA.DTMESCARD) RESTRICAO;

            IF @V_RESTRICAO > 0 BEGIN
               INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
               (CDFILIAL, CDSERVFILI)
                VALUES (@V_CDFILIAL, @V_CDSERVFILI);
            END
            ELSE BEGIN
               SET @V_RESTRICAO = 0;
            END;

         END;

         /*Utilizao de Pratos na Semana*/
         IF (@V_RESTRICAO = 0) BEGIN
            SELECT @V_RESTRICAO = CONVERT(DOUBLE PRECISION, COUNT(*))
            FROM UTILPRATSEM UP,
                 COMPCARD CC,
                 CARDADIA CA,
                 PRATO PR
            WHERE
               (UP.CDFILIAL     = @V_CDFILIAL)               AND
               (UP.CDSERVFILI   = @V_CDSERVFILI)    AND
               (CA.CDFILIAL     = @V_CDFILIAL)      AND
               (CA.CDSERVFILI   = @V_CDSERVFILI)    AND
               (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
               ( ((DATEPART(DW, CA.DTCARDAPIO) = '1') AND (UP.IDUTPRATDOM = 'N')) OR
                 ((DATEPART(DW, CA.DTCARDAPIO) = '2') AND (UP.IDUTPRATSEG = 'N')) OR
                 ((DATEPART(DW, CA.DTCARDAPIO) = '3') AND (UP.IDUTPRATTER = 'N')) OR
                 ((DATEPART(DW, CA.DTCARDAPIO) = '4') AND (UP.IDUTPRATQUA = 'N')) OR
                 ((DATEPART(DW, CA.DTCARDAPIO) = '5') AND (UP.IDUTPRATQUI = 'N')) OR
                 ((DATEPART(DW, CA.DTCARDAPIO) = '6') AND (UP.IDUTPRATSEX = 'N')) OR
                 ((DATEPART(DW, CA.DTCARDAPIO) = '7') AND (UP.IDUTPRATSAB = 'N'))) AND
               (CC.CDFILIAL     = @V_CDFILIAL)                        AND
               (CC.NRCARDAPIO   = CA.NRCARDAPIO)                     AND
               (CHARINDEX(UP.CDPRATO, CC.CDPRATO) = 1)               AND
               (PR.CDFILAUXPRAT = UP.CDFILAUXPRAT)                   AND
               (PR.CDPRATO      = UP.CDPRATO);

            IF @V_RESTRICAO > 0 BEGIN
               INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
               (CDFILIAL, CDSERVFILI)
                VALUES (@V_CDFILIAL, @V_CDSERVFILI);
            END
            ELSE BEGIN
               SET @V_RESTRICAO = 0;
            END;

         END;

         /*Limite de Nutrientes por Servio*/
         IF (@V_RESTRICAO = 0) BEGIN
            SELECT @V_RESTRICAO =  CONVERT(DOUBLE PRECISION, COUNT(*))
            FROM
               LIMNUTRI LN,
               NUTRIENTE NU,
               (SELECT
                  CDFILIAL,
                  CDSERVFILI,
                  DTCARDAPIO,
                  DTMESCARD,
                  CDNUTRIENTE,
                  SUM(QTNUTRIENTE) AS QTNUTRIENTE
                FROM
                   (SELECT
                       CA.CDFILIAL,
                       CA.CDSERVFILI,
                       CA.DTCARDAPIO,
                       CA.DTMESCARD,
                       CC.CDPRATO,
                       RS.CDPRODUTO,
                       NP.CDNUTRIENTE,
                       NP.QTNUTRPROD * 10 * PR.VRPESOUNID *
                       RS.QTUNIDESTSE AS QTNUTRIENTE
                    FROM
                       NUTRPROD NP,
                       PRODUTO PR,
                       RECESERV RS,
                       COMPCARD CC,
                       CARDADIA CA
                    WHERE
                       (CA.CDFILIAL     = @V_CDFILIAL)           AND
                       (CA.CDSERVFILI   = @V_CDSERVFILI)         AND
                       (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
                       (CC.CDFILIAL     = @V_CDFILIAL) AND
                       (CC.NRCARDAPIO   = CA.NRCARDAPIO)       AND
                       (CC.VRPECONSCARD = 100)                 AND
                       (RS.CDFILIAL     = @V_CDFILIAL) AND
                       (RS.CDSERVFILI   = @V_CDSERVFILI) AND
                       (RS.CDFILAUXPRAT = CC.CDFILAUXPRAT)     AND
                       (RS.CDPRATO      = CC.CDPRATO)          AND
                       (NP.CDPRODUTO    = RS.CDPRODUTO)        AND
                       (PR.CDPRODUTO    = RS.CDPRODUTO)

                    UNION ALL

                    SELECT
                       CA.CDFILIAL,
                       CA.CDSERVFILI,
                       CA.DTCARDAPIO,
                       CA.DTMESCARD,
                       CC.CDPRATO,
                       RF.CDPRODUTO,
                       NP.CDNUTRIENTE,
                       NP.QTNUTRPROD * 10 * PR.VRPESOUNID *
                       RF.QTUNIDESTLO AS QTNUTRIENTE
                    FROM
                       NUTRPROD NP,
                       PRODUTO PR,
                       RECEFILI RF,
                       COMPCARD CC,
                       CARDADIA CA
                    WHERE
                       (CA.CDFILIAL     = @V_CDFILIAL)                     AND
                       (CA.CDSERVFILI   = @V_CDSERVFILI)                   AND
                       (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)           AND
                       (CC.CDFILIAL     = @V_CDFILIAL)                     AND
                       (CC.NRCARDAPIO   = CA.NRCARDAPIO)                           AND
                       (CC.VRPECONSCARD = 100)                                     AND
                       (RF.CDFILIAL     = @V_CDFILIAL)                     AND
                       (RF.CDFILAUXPRAT = CC.CDFILAUXPRAT)                         AND
                       (RF.CDPRATO      = CC.CDPRATO)                              AND
                       (NP.CDPRODUTO    = RF.CDPRODUTO)                            AND
                       (PR.CDPRODUTO    = RF.CDPRODUTO)                            AND
                       NOT EXISTS (SELECT CDPRATO
                                   FROM RECESERV
                                   WHERE
                                      (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                      (CDPRATO      = CC.CDPRATO)      AND
                                      (CDFILIAL     = @V_CDFILIAL) AND
                                      (CDSERVFILI   = @V_CDSERVFILI)
                                   )

                    UNION ALL

                    SELECT
                       CA.CDFILIAL,
                       CA.CDSERVFILI,
                       CA.DTCARDAPIO,
                       CA.DTMESCARD,
                       CC.CDPRATO,
                       RP.CDPRODUTO,
                       NP.CDNUTRIENTE,
                       NP.QTNUTRPROD * 10 * PR.VRPESOUNID *
                       RP.QTUNIDESTPR AS QTNUTRIENTE
                    FROM
                       NUTRPROD NP,
                       PRODUTO PR,
                       RECEPADR RP,
                       COMPCARD CC,
                       CARDADIA CA
                    WHERE
                       (CA.CDFILIAL     = @V_CDFILIAL)                     AND
                       (CA.CDSERVFILI   = @V_CDSERVFILI)                   AND
                       (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)           AND
                       (CC.CDFILIAL     = @V_CDFILIAL)                     AND
                       (CC.NRCARDAPIO   = CA.NRCARDAPIO)                           AND
                       (CC.VRPECONSCARD = 100)                                     AND
                       (RP.CDFILAUXPRAT = 'P')                                     AND
                       (RP.CDPRATO      = CC.CDPRATO)                              AND
                       (NP.CDPRODUTO    = RP.CDPRODUTO)                            AND
                       (PR.CDPRODUTO    = RP.CDPRODUTO)                            AND
                       NOT EXISTS (SELECT CDPRATO
                                   FROM RECEFILI
                                   WHERE
                                      (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                      (CDPRATO      = CC.CDPRATO)      AND
                                      (CDFILIAL     = @V_CDFILIAL)
                                   )
                       AND
                       NOT EXISTS (SELECT CDPRATO
                                   FROM RECESERV
                                   WHERE
                                      (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                      (CDPRATO      = CC.CDPRATO)      AND
                                      (CDFILIAL     = @V_CDFILIAL) AND
                                      (CDSERVFILI   = @V_CDSERVFILI)
                                   )
                    ) A
                GROUP BY
                   CDFILIAL,
                   CDSERVFILI,
                   DTCARDAPIO,
                   DTMESCARD,
                   CDNUTRIENTE
                ) NC
            WHERE
               (LN.CDFILIAL    = @V_CDFILIAL)          AND
               (LN.CDSERVFILI  = @V_CDSERVFILI)        AND
               ((NC.QTNUTRIENTE < LN.QTMINLIMNUTR) OR
                (NC.QTNUTRIENTE > LN.QTMAXLIMNUTR))    AND
               (NC.CDNUTRIENTE = LN.CDNUTRIENTE)       AND
               (NU.CDNUTRIENTE = LN.CDNUTRIENTE);

            IF @V_RESTRICAO > 0 BEGIN
               INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
               (CDFILIAL, CDSERVFILI)
                VALUES (@V_CDFILIAL, @V_CDSERVFILI);
            END
            ELSE BEGIN
               SET @V_RESTRICAO = 0;
            END;

         END;

         /*Limite de Per Capita por Prato*/
         IF (@V_RESTRICAO = 0)BEGIN
            SELECT @V_RESTRICAO = CONVERT(DOUBLE PRECISION, COUNT(*))
            FROM LIMPEPRA LP,
                 PRATO PT,
                 PRODUTO PR,
               (SELECT
                   CA.CDFILIAL,
                   CA.CDSERVFILI,
                   CA.DTCARDAPIO,
                   CA.DTMESCARD,
                   CC.NRSEQPRATCAR,
                   CC.CDTIPOPRAT,
                   CC.CDFILAUXPRAT,
                   CC.CDPRATO,
                   CM.IDOPCCNFMES,
                   RS.CDPRODUTO,
                   RS.QTUNIDESTSE AS QTPRODUTO
                FROM
                   CARDADIA CA,
                   COMPCARD CC,
                   CNFCAMES CM,
                   RECESERV RS,
                   PRODUTO PR
                WHERE
                   (CA.CDFILIAL     = @V_CDFILIAL)             AND
                   (CA.CDSERVFILI   = @V_CDSERVFILI)           AND
                   (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)   AND
                   (CC.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
                   (CM.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CM.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
                   (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
                   (RS.CDFILIAL     = @V_CDFILIAL)                      AND
                   (RS.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (RS.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
                   (RS.CDPRATO      = CC.CDPRATO)                      AND
                   (PR.CDPRODUTO    = RS.CDPRODUTO)

                UNION ALL

                SELECT
                   CA.CDFILIAL,
                   CA.CDSERVFILI,
                   CA.DTCARDAPIO,
                   CA.DTMESCARD,
                   CC.NRSEQPRATCAR,
                   CC.CDTIPOPRAT,
                   CC.CDFILAUXPRAT,
                   CC.CDPRATO,
                   CM.IDOPCCNFMES,
                   RF.CDPRODUTO,
                   RF.QTUNIDESTLO AS QTPRODUTO
                FROM
                   CARDADIA CA,
                   COMPCARD CC,
                   CNFCAMES CM,
                   RECEFILI RF,
                   PRODUTO PR
                WHERE
                   (CA.CDFILIAL     = @V_CDFILIAL)             AND
                   (CA.CDSERVFILI   = @V_CDSERVFILI)           AND
                   (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)   AND
                   (CC.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
                   (CM.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CM.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
                   (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
                   (RF.CDFILIAL     = @V_CDFILIAL)                      AND
                   (RF.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
                   (RF.CDPRATO      = CC.CDPRATO)                      AND
                   (PR.CDPRODUTO    = RF.CDPRODUTO)                    AND
                   NOT EXISTS (SELECT
                                  CDPRATO
                               FROM
                                  RECESERV
                               WHERE
                                  (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                  (CDPRATO      = CC.CDPRATO)      AND
                                  (CDFILIAL     = @V_CDFILIAL)      AND
                                  (CDSERVFILI   = @V_CDSERVFILI)
                               )

                UNION ALL

                SELECT
                   CA.CDFILIAL,
                   CA.CDSERVFILI,
                   CA.DTCARDAPIO,
                   CA.DTMESCARD,
                   CC.NRSEQPRATCAR,
                   CC.CDTIPOPRAT,
                   CC.CDFILAUXPRAT,
                   CC.CDPRATO,
                   CM.IDOPCCNFMES,
                   RP.CDPRODUTO,
                   RP.QTUNIDESTPR AS QTPRODUTO
                FROM
                   CARDADIA CA,
                   COMPCARD CC,
                   CNFCAMES CM,
                   RECEPADR RP,
                   PRODUTO PR
                WHERE
                   (CA.CDFILIAL     = @V_CDFILIAL)             AND
                   (CA.CDSERVFILI   = @V_CDSERVFILI)           AND
                   (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)   AND
                   (CC.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
                   (CM.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CM.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
                   (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
                   (RP.CDFILAUXPRAT = 'P')                             AND
                   (RP.CDPRATO      = CC.CDPRATO)                      AND
                   (PR.CDPRODUTO    = RP.CDPRODUTO)                    AND
                   NOT EXISTS (SELECT
                                  CDPRATO
                               FROM
                                  RECEFILI
                               WHERE
                                  (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                  (CDPRATO      = CC.CDPRATO)      AND
                                  (CDFILIAL     = @V_CDFILIAL)
                               )                                   AND
                   NOT EXISTS (SELECT
                                  CDPRATO
                               FROM
                                  RECESERV
                               WHERE
                                  (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                  (CDPRATO      = CC.CDPRATO)      AND
                                  (CDFILIAL     = @V_CDFILIAL)      AND
                                  (CDSERVFILI   = @V_CDSERVFILI)
                               )
               ) PC
            WHERE
               (LP.CDFILIAL     = @V_CDFILIAL)                                             AND
               (LP.CDSERVFILI   = @V_CDSERVFILI)                                           AND
               (CHARINDEX(LP.CDPRODUTO, PC.CDPRODUTO) = 1)                                         AND
               (CHARINDEX(LP.CDPRATO, PC.CDPRATO) = 1)                                             AND
               ((PC.QTPRODUTO < LP.QTMINLIMPRAT) OR
                (PC.QTPRODUTO > LP.QTMAXLIMPRAT))                                         AND
               (PT.CDFILAUXPRAT = LP.CDFILAUXPRAT)                                        AND
               (PT.CDPRATO      = LP.CDPRATO)                                             AND
               (PR.CDPRODUTO    = LP.CDPRODUTO);

            IF @V_RESTRICAO > 0 BEGIN
               INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
               (CDFILIAL, CDSERVFILI)
                VALUES (@V_CDFILIAL, @V_CDSERVFILI);
            END
            ELSE BEGIN
               SET @V_RESTRICAO = 0;
            END;

         END;

         /*Limite de Per Capita por Servio*/
         IF (@V_RESTRICAO = 0) BEGIN
            SELECT @V_RESTRICAO = CONVERT(DOUBLE PRECISION, COUNT(*))
              FROM LIMPESER LP,
                   PRODUTO PR,
               (SELECT
                   CA.CDFILIAL,
                   CA.CDSERVFILI,
                   CA.DTCARDAPIO,
                   CA.DTMESCARD,
                   CC.NRSEQPRATCAR,
                   CC.CDTIPOPRAT,
                   CC.CDFILAUXPRAT,
                   CC.CDPRATO,
                   CM.IDOPCCNFMES,
                   RS.CDPRODUTO,
                   RS.QTUNIDESTSE AS QTPRODUTO
                FROM
                   CARDADIA CA,
                   COMPCARD CC,
                   CNFCAMES CM,
                   RECESERV RS,
                   PRODUTO PR
                WHERE
                   (CA.CDFILIAL     = @V_CDFILIAL)             AND
                   (CA.CDSERVFILI   = @V_CDSERVFILI)           AND
                   (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)   AND
                   (CC.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
                   (CM.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CM.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
                   (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
                   (RS.CDFILIAL     = @V_CDFILIAL)                      AND
                   (RS.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (RS.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
                   (RS.CDPRATO      = CC.CDPRATO)                      AND
                   (PR.CDPRODUTO    = RS.CDPRODUTO)

                UNION ALL

                SELECT
                   CA.CDFILIAL,
                   CA.CDSERVFILI,
                   CA.DTCARDAPIO,
                   CA.DTMESCARD,
                   CC.NRSEQPRATCAR,
                   CC.CDTIPOPRAT,
                   CC.CDFILAUXPRAT,
                   CC.CDPRATO,
                   CM.IDOPCCNFMES,
                   RF.CDPRODUTO,
                   RF.QTUNIDESTLO AS QTPRODUTO
                FROM
                   CARDADIA CA,
                   COMPCARD CC,
                   CNFCAMES CM,
                   RECEFILI RF,
                   PRODUTO PR
                WHERE
                   (CA.CDFILIAL     = @V_CDFILIAL)             AND
                   (CA.CDSERVFILI   = @V_CDSERVFILI)           AND
                   (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)   AND
                   (CC.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
                   (CM.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CM.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
                   (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
                   (RF.CDFILIAL     = @V_CDFILIAL)                      AND
                   (RF.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
                   (RF.CDPRATO      = CC.CDPRATO)                      AND
                   (PR.CDPRODUTO    = RF.CDPRODUTO)                    AND
                   NOT EXISTS (SELECT
                                  CDPRATO
                               FROM
                                  RECESERV
                               WHERE
                                  (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                  (CDPRATO      = CC.CDPRATO)      AND
                                  (CDFILIAL     = @V_CDFILIAL)      AND
                                  (CDSERVFILI   = @V_CDSERVFILI)
                               )

                UNION ALL

                SELECT
                   CA.CDFILIAL,
                   CA.CDSERVFILI,
                   CA.DTCARDAPIO,
                   CA.DTMESCARD,
                   CC.NRSEQPRATCAR,
                   CC.CDTIPOPRAT,
                   CC.CDFILAUXPRAT,
                   CC.CDPRATO,
                   CM.IDOPCCNFMES,
                   RP.CDPRODUTO,
                   RP.QTUNIDESTPR AS QTPRODUTO
                FROM
                   CARDADIA CA,
                   COMPCARD CC,
                   CNFCAMES CM,
                   RECEPADR RP,
                   PRODUTO PR
                WHERE
                   (CA.CDFILIAL     = @V_CDFILIAL)             AND
                   (CA.CDSERVFILI   = @V_CDSERVFILI)           AND
                   (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)   AND
                   (CC.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
                   (CM.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CM.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
                   (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
                   (RP.CDFILAUXPRAT = 'P')                             AND
                   (RP.CDPRATO      = CC.CDPRATO)                      AND
                   (PR.CDPRODUTO    = RP.CDPRODUTO)                    AND
                   NOT EXISTS (SELECT
                                  CDPRATO
                               FROM
                                  RECEFILI
                               WHERE
                                  (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                  (CDPRATO      = CC.CDPRATO)      AND
                                  (CDFILIAL     = @V_CDFILIAL)
                               )
                   AND
                   NOT EXISTS (SELECT
                                  CDPRATO
                               FROM
                                  RECESERV
                               WHERE
                                  (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                  (CDPRATO      = CC.CDPRATO)      AND
                                  (CDFILIAL     = @V_CDFILIAL)     AND
                                  (CDSERVFILI   = @V_CDSERVFILI)
                               )
                ) PC
            WHERE
               (LP.CDFILIAL   = @V_CDFILIAL)   AND
               (LP.CDSERVFILI = @V_CDSERVFILI) AND
               (CHARINDEX(LP.CDPRODUTO, PC.CDPRODUTO) = 1)                                         AND
               ((PC.QTPRODUTO < LP.QTMINLIMSERV) OR
                (PC.QTPRODUTO > LP.QTMAXLIMSERV))      AND
               (PR.CDPRODUTO  = LP.CDPRODUTO);

            IF @V_RESTRICAO > 0 BEGIN
               INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
               (CDFILIAL, CDSERVFILI)
                VALUES (@V_CDFILIAL, @V_CDSERVFILI);
            END
            ELSE BEGIN
               SET @V_RESTRICAO = 0;
            END;

         END;

         /*Restrio de Produtos */
         IF (@V_RESTRICAO = 0 ) BEGIN
            SELECT @V_RESTRICAO = CONVERT(DOUBLE PRECISION, COUNT(*))
            FROM
               RESTPROD RP,
               PRODUTO PR,
               (SELECT
                   CA.CDFILIAL,
                   CA.CDSERVFILI,
                   CA.DTCARDAPIO,
                   CA.DTMESCARD,
                   CC.NRSEQPRATCAR,
                   CC.CDTIPOPRAT,
                   CC.CDFILAUXPRAT,
                   CC.CDPRATO,
                   CM.IDOPCCNFMES,
                   RS.CDPRODUTO,
                   RS.QTUNIDESTSE AS QTPRODUTO,
                   PR.CDARVPROD
                FROM
                   CARDADIA CA,
                   COMPCARD CC,
                   CNFCAMES CM,
                   RECESERV RS,
                   PRODUTO PR
                WHERE
                   (CA.CDFILIAL     = @V_CDFILIAL)             AND
                   (CA.CDSERVFILI   = @V_CDSERVFILI)           AND
                   (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)   AND
                   (CC.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
                   (CM.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CM.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
                   (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
                   (RS.CDFILIAL     = @V_CDFILIAL)                      AND
                   (RS.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (RS.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
                   (RS.CDPRATO      = CC.CDPRATO)                      AND
                   (PR.CDPRODUTO    = RS.CDPRODUTO)

                UNION ALL

                SELECT
                   CA.CDFILIAL,
                   CA.CDSERVFILI,
                   CA.DTCARDAPIO,
                   CA.DTMESCARD,
                   CC.NRSEQPRATCAR,
                   CC.CDTIPOPRAT,
                   CC.CDFILAUXPRAT,
                   CC.CDPRATO,
                   CM.IDOPCCNFMES,
                   RF.CDPRODUTO,
                   RF.QTUNIDESTLO AS QTPRODUTO,
                   PR.CDARVPROD
                FROM
                   CARDADIA CA,
                   COMPCARD CC,
                   CNFCAMES CM,
                   RECEFILI RF,
                   PRODUTO PR
                WHERE
                   (CA.CDFILIAL     = @V_CDFILIAL)             AND
                   (CA.CDSERVFILI   = @V_CDSERVFILI)           AND
                   (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)   AND
                   (CC.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
                   (CM.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CM.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
                   (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
                   (RF.CDFILIAL     = @V_CDFILIAL)                      AND
                   (RF.CDFILAUXPRAT = CC.CDFILAUXPRAT)                 AND
                   (RF.CDPRATO      = CC.CDPRATO)                      AND
                   (PR.CDPRODUTO    = RF.CDPRODUTO)                    AND
                   NOT EXISTS (SELECT
                                  CDPRATO
                               FROM
                                  RECESERV
                               WHERE
                                  (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                  (CDPRATO      = CC.CDPRATO)      AND
                                  (CDFILIAL     = @V_CDFILIAL)      AND
                                  (CDSERVFILI   = @V_CDSERVFILI)
                               )

                UNION ALL

                SELECT
                   CA.CDFILIAL,
                   CA.CDSERVFILI,
                   CA.DTCARDAPIO,
                   CA.DTMESCARD,
                   CC.NRSEQPRATCAR,
                   CC.CDTIPOPRAT,
                   CC.CDFILAUXPRAT,
                   CC.CDPRATO,
                   CM.IDOPCCNFMES,
                   RP.CDPRODUTO,
                   RP.QTUNIDESTPR AS QTPRODUTO,
                   PR.CDARVPROD
                FROM
                   CARDADIA CA,
                   COMPCARD CC,
                   CNFCAMES CM,
                   RECEPADR RP,
                   PRODUTO PR
                WHERE
                   (CA.CDFILIAL     = @V_CDFILIAL)             AND
                   (CA.CDSERVFILI   = @V_CDSERVFILI)           AND
                   (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL)   AND
                   (CC.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CC.NRCARDAPIO   = CA.NRCARDAPIO)                   AND
                   (CM.CDFILIAL     = @V_CDFILIAL)                      AND
                   (CM.CDSERVFILI   = @V_CDSERVFILI)                    AND
                   (CM.DTREFECNFMES = CA.DTMESCARD)                    AND
                   (CM.NRSEQCNFMES  = CC.NRSEQPRATCAR)                 AND
                   (RP.CDFILAUXPRAT = 'P')                             AND
                   (RP.CDPRATO      = CC.CDPRATO)                      AND
                   (PR.CDPRODUTO    = RP.CDPRODUTO)                    AND
                   NOT EXISTS (SELECT
                                  CDPRATO
                               FROM
                                  RECEFILI
                               WHERE
                                  (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                  (CDPRATO      = CC.CDPRATO)      AND
                                  (CDFILIAL     = @V_CDFILIAL)
                               )
                   AND
                   NOT EXISTS (SELECT
                                  CDPRATO
                               FROM
                                  RECESERV
                               WHERE
                                  (CDFILAUXPRAT = CC.CDFILAUXPRAT) AND
                                  (CDPRATO      = CC.CDPRATO)      AND
                                  (CDFILIAL     = @V_CDFILIAL)     AND
                                  (CDSERVFILI   = @V_CDSERVFILI)
                               )
                ) PC
            WHERE
               (RP.CDFILIAL   = @V_CDFILIAL)   AND
               (RP.CDSERVFILI = @V_CDSERVFILI) AND
               (CHARINDEX(PC.CDARVPROD, PR.CDARVPROD) = 1)    AND
               (PR.CDPRODUTO  = RP.CDPRODUTO);

            IF @V_RESTRICAO > 0 BEGIN
               INSERT INTO @RESTR_CONTRATUAIS_CARD_TABLE
               (CDFILIAL, CDSERVFILI)
                VALUES (@V_CDFILIAL, @V_CDSERVFILI);
            END
            ELSE BEGIN
               SET @V_RESTRICAO = 0;
            END;

         END;

         SET @V_RESTRICAO = 0;
      END;
      FETCH NEXT FROM CUR_FILIAL INTO @V_CDFILIAL, @V_CDSERVFILI;
   END;

   CLOSE CUR_FILIAL;
   DEALLOCATE CUR_FILIAL;
   RETURN;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'RESTR_CONTRATUAIS_CARD','6.19.000';
GO
